@@ -2,7 +2,7 @@ import numpy as np
 from pathlib import Path
 from typing import Tuple, Union, Optional
 
-# Nuevo: usamos la Config moderna
+
 from openvancy.utils.config_loader import Config as V1Config
 
 
@@ -18,36 +18,32 @@ class CrystalStructureGenerator:
     """
 
     def __init__(self, config: Union[V1Config, dict], out_dir: Path):
-        # Aceptar tanto Config v1 como dict legacy
+        
         if isinstance(config, V1Config):
             self.cfg: V1Config = config
         elif isinstance(config, dict):
-            # Compatibilidad con JSON viejo
             self.cfg = V1Config.from_dict(config)
         else:
             raise TypeError(f"Config debe ser V1Config o dict, no {type(config)}")
 
-        # Directorio de salida
-        self.out_dir = Path(out_dir).expanduser().resolve()
+        self.out_dir = Path(out_dir).expanduser().resolve() / "dump"
         self.out_dir.mkdir(parents=True, exist_ok=True)
 
-        # ---- Rutas de entrada (defect) ----
         if not self.cfg.paths.defect_inputs:
             raise ValueError("paths.defect_inputs está vacío en la configuración.")
         self.path_defect: Path = Path(self.cfg.paths.defect_inputs[0]).expanduser().resolve()
         if not self.path_defect.exists():
             raise FileNotFoundError(f"No se encontró el archivo de defecto: {self.path_defect}")
 
-        # ---- Parámetros de referencia (red a generar) ----
-        self.structure_type: str = str(self.cfg.reference.lattice).lower().strip()  # 'bcc' | 'fcc'
+  
+        self.structure_type: str = str(self.cfg.reference.lattice).lower().strip()  
         self.a0: float = float(self.cfg.reference.a0)
         rx, ry, rz = self.cfg.reference.cells
         self.reps: Tuple[int, int, int] = (int(rx), int(ry), int(rz))
 
-        # Leer box bounds y centro del archivo de defecto
+       
         self._read_defect_box()
 
-    # ---------------- Internos ----------------
 
     def _read_defect_box(self) -> None:
         """
